=== modified file 'NEWS'
--- NEWS	2012-07-09 15:23:26 +0000
+++ NEWS	2012-03-23 15:02:38 +0000
@@ -13,12 +13,6 @@
 
   * Fix searching in tree views. (Jelmer Vernooij, #928301)
 
- CHANGES
-
-  * bzr-notify has been removed, as it was causing regressions
-    on several machines and not particularly useful.
-    (Jelmer Vernooij, #714767, #949798, #998994, #342135, #342136, #394536)
-
 0.103.0	2011-12-11
 
  FEATURES

=== added file 'bzr-notify'
--- bzr-notify	1970-01-01 00:00:00 +0000
+++ bzr-notify	2012-02-03 19:49:55 +0000
@@ -0,0 +1,102 @@
+#!/usr/bin/env python
+
+"""Run the bzr tray icon.
+
+This is a background program which will pop up a notification on the users
+screen when a commit occurs.
+"""
+
+from bzrlib.plugin import load_plugins
+load_plugins()
+
+from bzrlib.plugins.gtk.commands import open_display
+
+from bzrlib.plugins.gtk.notify import NotifyPopupMenu
+Gtk = open_display()
+
+import cgi
+import sys
+
+import dbus
+import dbus.service
+from gi.repository import GObject
+from gi.repository import Notify
+
+from bzrlib.bzrdir import BzrDir
+from bzrlib.osutils import format_date
+from bzrlib.transport import get_transport
+
+menu = NotifyPopupMenu()
+try:
+    from gi.repository import AppIndicator3
+except ImportError:
+    icon = Gtk.StatusIcon.new_from_icon_name("bzr-panel")
+    icon.connect('popup-menu', menu.display)
+    icon.set_visible(False)
+    hide_icon = lambda: icon.set_visible(False)
+    show_icon = lambda: icon.set_visible(True)
+else:
+    indicator = AppIndicator3.Indicator.new(
+        "bzr-gtk-notify", "bzr-panel", AppIndicator3.IndicatorCategory.OTHER)
+    indicator.set_status (AppIndicator3.IndicatorStatus.PASSIVE)
+    indicator.set_attention_icon("bzr-panel")
+    indicator.set_menu(menu)
+    hide_icon = lambda: indicator.set_status (
+        AppIndicator3.IndicatorStatus.PASSIVE)
+    show_icon = lambda: indicator.set_status (
+        AppIndicator3.IndicatorStatus.ATTENTION)
+
+if getattr(dbus, 'version', (0,0,0)) >= (0,41,0):
+    import dbus.glib
+BROADCAST_INTERFACE = "org.bazaarvcs.plugins.dbus.Broadcast"
+bus = dbus.SessionBus()
+
+def catch_branch(revision_id, urls):
+    # TODO: show all the urls, or perhaps choose the 'best'.
+    url = urls[0]
+    try:
+        if isinstance(revision_id, unicode):
+            revision_id = revision_id.encode('utf8')
+        transport = get_transport(url)
+        a_dir = BzrDir.open_from_transport(transport)
+        branch = a_dir.open_branch()
+        revno = branch.revision_id_to_revno(revision_id)
+        revision = branch.repository.get_revision(revision_id)
+        summary = 'New revision %d in %s' % (revno, url)
+        body = 'Committer: %s\n' % revision.committer
+        body += 'Date: %s\n' % format_date(revision.timestamp,
+            revision.timezone)
+        body += '\n'
+        body += revision.message
+        body = cgi.escape(body)
+        nw = Notify.Notification.new(summary, body, None)
+        def start_viz(notification=None, action=None, data=None):
+            """Start the viz program."""
+            from bzrlib.plugins.gtk.commands import start_viz_window
+            pp = start_viz_window(branch, revision_id)
+            pp.show()
+        def start_branch(notification=None, action=None, data=None):
+            """Start a Branch dialog"""
+            from bzrlib.plugins.gtk.branch import BranchDialog
+            bd = BranchDialog(remote_path=url)
+            bd.run()
+        if "actions" in Notify.get_server_caps():
+            nw.add_action("inspect", "Inspect", start_viz, None)
+            nw.add_action("branch", "Branch", start_branch, None)
+        show_icon()
+        GObject.timeout_add(5000, hide_icon)
+        nw.set_timeout(5000)
+        nw.show()
+    except Exception, e:
+        print e
+        raise
+bus.add_signal_receiver(catch_branch,
+                        dbus_interface=BROADCAST_INTERFACE,
+                        signal_name="Revision")
+Notify.init("bzr-notify")
+
+if sys.argv[-1] == 'test':
+    # Exit before main loop.
+    sys.exit(0)
+
+Gtk.main()

=== added file 'bzr-notify.desktop'
--- bzr-notify.desktop	1970-01-01 00:00:00 +0000
+++ bzr-notify.desktop	2011-09-28 07:45:39 +0000
@@ -0,0 +1,12 @@
+[Desktop Entry]
+Type=Application
+Version=0.1
+Name=Bazaar Notification
+GenericName=Bazaar Notification
+Comment=Notification Area Icon for Bazaar
+Icon=bzr-icon-64
+Exec=bzr-notify
+Categories=Application;Development;RevisionControl;
+Terminal=false
+X-GNOME-Autostart-Delay=30
+

=== added file 'bzr-notify.desktop.in'
--- bzr-notify.desktop.in	1970-01-01 00:00:00 +0000
+++ bzr-notify.desktop.in	2010-08-21 09:32:13 +0000
@@ -0,0 +1,10 @@
+[Desktop Entry]
+Type=Application
+Version=0.1
+_Name=Bazaar Notification
+_GenericName=Bazaar Notification
+_Comment=Notification Area Icon for Bazaar
+Icon=bzr-icon-64
+Exec=bzr-notify
+Categories=Application;Development;RevisionControl;
+Terminal=false

=== added file 'notify.py'
--- notify.py	1970-01-01 00:00:00 +0000
+++ notify.py	2012-02-03 18:59:38 +0000
@@ -0,0 +1,104 @@
+# Copyright (C) 2007 by Robert Collins
+#                       Jelmer Vernooij
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+"""Notification area icon and notification for Bazaar."""
+
+from gi.repository import Gtk
+import bzrlib
+
+
+def has_dbus():
+    return (getattr(bzrlib.plugins, "dbus", None) is not None)
+
+
+def has_avahi():
+    return (getattr(bzrlib.plugins, "avahi", None) is not None)
+
+
+class NotifyPopupMenu(Gtk.Menu):
+
+    SHOW_WIDGETS = True
+
+    def __init__(self):
+        super(NotifyPopupMenu, self).__init__()
+        self.create_items()
+
+    def create_items(self):
+        from bzrlib import errors
+        item = Gtk.CheckMenuItem.new_with_mnemonic('_Gateway to LAN')
+        item.connect('toggled', self.toggle_lan_gateway)
+        self.append(item)
+        self.append(Gtk.SeparatorMenuItem())
+        try:
+            from bzrlib.plugins.dbus.activity import LanGateway
+            self.langateway = LanGateway()
+        except ImportError:
+            item.set_sensitive(False)
+        except errors.BzrError:
+            # FIXME: Should only catch errors that indicate a lan-notify
+            # process is already running.
+            item.set_sensitive(False)
+
+        item = Gtk.CheckMenuItem.new_with_mnemonic(
+            'Announce _branches on LAN')
+        item.connect('toggled', self.toggle_announce_branches)
+        self.append(item)
+        self.append(Gtk.SeparatorMenuItem())
+        try:
+            from bzrlib.plugins.avahi.share import ZeroConfServer
+            from bzrlib import urlutils
+            self.zeroconfserver = ZeroConfServer(urlutils.normalize_url('.'))
+        except ImportError:
+            item.set_sensitive(False)
+
+        item = Gtk.ImageMenuItem.new_from_stock(Gtk.STOCK_PREFERENCES, None)
+        item.connect('activate', self.show_preferences)
+        self.append(item)
+        item = Gtk.ImageMenuItem.new_from_stock(Gtk.STOCK_ABOUT, None)
+        item.connect('activate', self.show_about)
+        self.append(item)
+        self.append(Gtk.SeparatorMenuItem())
+        item = Gtk.ImageMenuItem.new_from_stock(Gtk.STOCK_QUIT, None)
+        item.connect('activate', Gtk.main_quit)
+        self.append(item)
+        if self.SHOW_WIDGETS:
+            self.show_all()
+
+    def display(self, icon, event_button, event_time):
+        self.popup(None, None, Gtk.status_icon_position_menu,
+               event_button, event_time, icon)
+
+    def toggle_lan_gateway(self, item):
+        if item.get_active():
+            self.langateway.start()
+        else:
+            self.langateway.stop()
+
+    def toggle_announce_branches(self, item):
+        if item.get_active():
+            self.zeroconfserver.start()
+        else:
+            self.zeroconfserver.close()
+
+    def show_about(self, item):
+        from bzrlib.plugins.gtk.about import AboutDialog
+        dialog = AboutDialog()
+        dialog.run()
+
+    def show_preferences(self, item):
+        from bzrlib.plugins.gtk.preferences import PreferencesWindow
+        prefs = PreferencesWindow()
+        prefs.run()

=== modified file 'setup.py'
--- setup.py	2012-07-09 15:23:26 +0000
+++ setup.py	2012-02-28 17:45:56 +0000
@@ -148,7 +148,7 @@
         maintainer_email="jelmer@samba.org",
         description="GTK+ Frontends for various Bazaar commands",
         license="GNU GPL v2 or later",
-        scripts=['bzr-handle-patch'],
+        scripts=['bzr-handle-patch', 'bzr-notify'],
         url="http://bazaar-vcs.org/BzrGtk",
         package_dir={
             "bzrlib.plugins.gtk": ".",
@@ -188,7 +188,8 @@
                     # In case Python distutils extra is not available,
                     # install the .desktop files
                     ('share/applications', ['bazaar-properties.desktop',
-                                            'bzr-handle-patch.desktop']),
+                                            'bzr-handle-patch.desktop',
+                                            'bzr-notify.desktop']),
                     ('share/application-registry', ['bzr-gtk.applications']),
                     ('share/pixmaps', ['icons/bzr-icon-64.png']),
                     ('share/icons/hicolor/scalable/apps',

